@@ -5,7 +5,7 @@ from seleniumbase.translate.korean import 셀레늄_테스트_케이스  # noqa
 class 테스트_클래스(셀레늄_테스트_케이스):
 
     def test_실시예_1(self):
-        self.URL_열기("https://ko.wikipedia.org/wiki/")
+        self.열기("https://ko.wikipedia.org/wiki/")
         self.텍스트_확인("위키백과")
         self.요소_확인('[title="위키백과:소개"]')
         self.텍스트를_업데이트("#searchInput", "김치")
