@@ -451,7 +451,8 @@ def get_remote_driver(
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.FIREFOX:
         try:
             # Use Geckodriver for Firefox if it's on the PATH
@@ -469,7 +470,8 @@ def get_remote_driver(
             return webdriver.Remote(
                 command_executor=address,
                 desired_capabilities=capabilities,
-                browser_profile=profile)
+                browser_profile=profile,
+                keep_alive=True)
         except WebDriverException:
             # Don't use Geckodriver: Only works for old versions of Firefox
             profile = _create_firefox_profile(
@@ -485,35 +487,40 @@ def get_remote_driver(
             return webdriver.Remote(
                 command_executor=address,
                 desired_capabilities=capabilities,
-                browser_profile=profile)
+                browser_profile=profile,
+                keep_alive=True)
     elif browser_name == constants.Browser.INTERNET_EXPLORER:
         capabilities = webdriver.DesiredCapabilities.INTERNETEXPLORER
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.EDGE:
         capabilities = webdriver.DesiredCapabilities.EDGE
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.SAFARI:
         capabilities = webdriver.DesiredCapabilities.SAFARI
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.OPERA:
         capabilities = webdriver.DesiredCapabilities.OPERA
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.PHANTOM_JS:
         capabilities = webdriver.DesiredCapabilities.PHANTOMJS
         for key in desired_caps.keys():
@@ -523,32 +530,37 @@ def get_remote_driver(
             warnings.simplefilter("ignore", category=UserWarning)
             return webdriver.Remote(
                 command_executor=address,
-                desired_capabilities=capabilities)
+                desired_capabilities=capabilities,
+                keep_alive=True)
     elif browser_name == constants.Browser.ANDROID:
         capabilities = webdriver.DesiredCapabilities.ANDROID
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.IPHONE:
         capabilities = webdriver.DesiredCapabilities.IPHONE
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.IPAD:
         capabilities = webdriver.DesiredCapabilities.IPAD
         for key in desired_caps.keys():
             capabilities[key] = desired_caps[key]
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=capabilities)
+            desired_capabilities=capabilities,
+            keep_alive=True)
     elif browser_name == constants.Browser.REMOTE:
         return webdriver.Remote(
             command_executor=address,
-            desired_capabilities=desired_caps)
+            desired_capabilities=desired_caps,
+            keep_alive=True)
 
 
 def get_local_driver(
@@ -721,7 +733,18 @@ def get_local_driver(
                     print("\nWarning: chromedriver not found. Installing now:")
                     sb_install.main(override="chromedriver")
                     sys.argv = sys_args  # Put back the original sys args
-            return webdriver.Chrome(options=chrome_options)
+            if not headless or "linux" not in PLATFORM:
+                return webdriver.Chrome(options=chrome_options)
+            else:  # Running headless on Linux
+                try:
+                    return webdriver.Chrome(options=chrome_options)
+                except Exception:
+                    # Use the virtual display on Linux during headless errors
+                    logging.debug("\nWarning: Chrome failed to launch in"
+                                  " headless mode. Attempting to use the"
+                                  " SeleniumBase virtual display on Linux...")
+                    chrome_options.headless = False
+                    return webdriver.Chrome(options=chrome_options)
         except Exception as e:
             if headless:
                 raise Exception(e)
