@@ -7,14 +7,17 @@ import traceback
 from seleniumbase.config import settings
 
 
-def log_screenshot(test_logpath, driver):
+def log_screenshot(test_logpath, driver, screenshot=None, get=False):
     screenshot_name = settings.SCREENSHOT_NAME
     screenshot_path = "%s/%s" % (test_logpath, screenshot_name)
     try:
-        element = driver.find_element_by_tag_name('body')
-        element_png = element.screenshot_as_png
+        if not screenshot:
+            element = driver.find_element_by_tag_name('body')
+            screenshot = element.screenshot_as_base64
         with open(screenshot_path, "wb") as file:
-            file.write(element_png)
+            file.write(screenshot)
+        if get:
+            return screenshot
     except Exception:
         try:
             driver.get_screenshot_as_file(screenshot_path)
@@ -22,15 +25,19 @@ def log_screenshot(test_logpath, driver):
             print("WARNING: Unable to get screenshot for failure logs!")
 
 
-def log_test_failure_data(test, test_logpath, driver, browser):
+def log_test_failure_data(test, test_logpath, driver, browser, url=None):
     basic_info_name = settings.BASIC_INFO_NAME
     basic_file_path = "%s/%s" % (test_logpath, basic_info_name)
     log_file = codecs.open(basic_file_path, "w+", "utf-8")
-    last_page = get_last_page(driver)
+    if url:
+        last_page = url
+    else:
+        last_page = get_last_page(driver)
     data_to_save = []
-    data_to_save.append("Last_Page: %s" % last_page)
-    data_to_save.append("Browser: %s " % browser)
-    if sys.version.startswith('3') and hasattr(test, '_outcome'):
+    data_to_save.append("Last Page: %s" % last_page)
+    data_to_save.append("  Browser: %s" % browser)
+    data_to_save.append("Timestamp: %s" % int(time.time()))
+    if sys.version_info[0] >= 3 and hasattr(test, '_outcome'):
         if test._outcome.errors:
             try:
                 exc_message = test._outcome.errors[0][1][1]
@@ -52,13 +59,16 @@ def log_test_failure_data(test, test_logpath, driver, browser):
     log_file.close()
 
 
-def log_page_source(test_logpath, driver):
+def log_page_source(test_logpath, driver, source=None):
     html_file_name = settings.PAGE_SOURCE_NAME
-    try:
-        page_source = driver.page_source
-    except Exception:
-        # Since we can't get the page source from here, skip saving it
-        return
+    if source:
+        page_source = source
+    else:
+        try:
+            page_source = driver.page_source
+        except Exception:
+            # Since we can't get the page source from here, skip saving it
+            return
     html_file_path = "%s/%s" % (test_logpath, html_file_name)
     html_file = codecs.open(html_file_path, "w+", "utf-8")
     rendered_source = get_html_source_with_base_href(driver, page_source)
@@ -101,7 +111,49 @@ def get_html_source_with_base_href(driver, page_source):
     return ''
 
 
-def log_folder_setup(log_path):
+def copytree(src, dst, symlinks=False, ignore=None):
+    if not os.path.exists(dst):
+        os.makedirs(dst)
+    for item in os.listdir(src):
+        s = os.path.join(src, item)
+        d = os.path.join(dst, item)
+        if os.path.isdir(s):
+            copytree(s, d, symlinks, ignore)
+        else:
+            if not os.path.exists(d) or (
+                    os.stat(s).st_mtime - os.stat(d).st_mtime > 1):
+                shutil.copy2(s, d)
+
+
+def archive_logs_if_set(log_path, archive_logs=False):
+    """ Handle Logging """
+    arg_join = " ".join(sys.argv)
+    if ("-n" in sys.argv) or ("-n=" in arg_join) or (arg_join == "-c"):
+        return  # Skip if multithreaded
+    if log_path.endswith("/"):
+        log_path = log_path[:-1]
+    if not os.path.exists(log_path):
+        try:
+            os.makedirs(log_path)
+        except Exception:
+            pass  # Only reachable during multi-threaded runs
+    else:
+        if settings.ARCHIVE_EXISTING_LOGS or archive_logs:
+            if len(os.listdir(log_path)) > 0:
+                archived_folder = "%s/../archived_logs/" % log_path
+                archived_folder = os.path.realpath(archived_folder) + '/'
+                log_path = os.path.realpath(log_path) + '/'
+                if not os.path.exists(archived_folder):
+                    try:
+                        os.makedirs(archived_folder)
+                    except Exception:
+                        pass  # Only reachable during multi-threaded runs
+                time_id = str(int(time.time()))
+                archived_logs = "%slogs_%s" % (archived_folder, time_id)
+                copytree(log_path, archived_logs)
+
+
+def log_folder_setup(log_path, archive_logs=False):
     """ Handle Logging """
     if log_path.endswith("/"):
         log_path = log_path[:-1]
@@ -112,18 +164,27 @@ def log_folder_setup(log_path):
             pass  # Should only be reachable during multi-threaded runs
     else:
         archived_folder = "%s/../archived_logs/" % log_path
+        archived_folder = os.path.realpath(archived_folder) + '/'
         if not os.path.exists(archived_folder):
             try:
                 os.makedirs(archived_folder)
             except Exception:
                 pass  # Should only be reachable during multi-threaded runs
-        if not "".join(sys.argv) == "-c":
-            # Only move log files if the test run is not multi-threaded.
-            # (Running tests with "-n NUM" will create threads that only
-            # have "-c" in the sys.argv list. Easy to catch.)
-            archived_logs = "%slogs_%s" % (
-                archived_folder, int(time.time()))
-            shutil.move(log_path, archived_logs)
-            os.makedirs(log_path)
-            if not settings.ARCHIVE_EXISTING_LOGS:
+        archived_logs = "%slogs_%s" % (
+            archived_folder, int(time.time()))
+
+        if len(os.listdir(log_path)) > 0:
+            try:
+                shutil.move(log_path, archived_logs)
+                os.makedirs(log_path)
+            except Exception:
+                pass  # A file was probably open at the time
+            if not settings.ARCHIVE_EXISTING_LOGS and not archive_logs:
                 shutil.rmtree(archived_logs)
+            else:
+                a_join = " ".join(sys.argv)
+                if ("-n" in sys.argv) or ("-n=" in a_join) or (a_join == "-c"):
+                    # Logs are saved/archived now if tests are multithreaded
+                    pass
+                else:
+                    shutil.rmtree(archived_logs)  # (Archive test run later)
