@@ -34,7 +34,7 @@ def pytest_addoption(parser):
     --headed  (The option to run tests with a GUI on Linux OS.)
     --start-page=URL  (The starting URL for the web browser when tests begin.)
     --archive-logs  (Archive old log files instead of deleting them.)
-    --time-limit  (The option to set a time limit per test before failing it.)
+    --time-limit=SECONDS  (Safely fail any test that exceeds the limit limit.)
     --slow  (The option to slow down the automation.)
     --demo  (The option to visually see test actions as they occur.)
     --demo-sleep=SECONDS  (The option to wait longer after Demo Mode actions.)
@@ -46,12 +46,11 @@ def pytest_addoption(parser):
     --disable-csp  (This disables the Content Security Policy of websites.)
     --enable-sync  (The option to enable "Chrome Sync".)
     --use-auto-ext  (The option to use Chrome's automation extension.)
-    --no-sandbox  (The option to enable Chrome's "No-Sandbox" feature.)
-    --disable-gpu  (The option to enable Chrome's "Disable GPU" feature.)
     --incognito  (The option to enable Chrome's Incognito mode.)
     --guest  (The option to enable Chrome's Guest mode.)
     --devtools  (The option to open Chrome's DevTools when the browser opens.)
     --reuse-session  (The option to reuse the browser session between tests.)
+    --crumbs  (Option to delete all cookies between tests reusing a session.)
     --maximize  (The option to start with the web browser maximized.)
     --save-screenshot  (The option to save a screenshot after each test.)
     --visual-baseline  (Set the visual baseline for Visual/Layout tests.)
@@ -325,7 +324,7 @@ def pytest_addoption(parser):
                      default=False,
                      help="""The option to check for JavaScript errors after
                           every page load.""")
-    parser.addoption('--ad_block', '--ad-block',
+    parser.addoption('--ad_block', '--ad-block', '--block_ads', '--block-ads',
                      action="store_true",
                      dest='ad_block_on',
                      default=False,
@@ -363,12 +362,14 @@ def pytest_addoption(parser):
                      action="store_true",
                      dest='no_sandbox',
                      default=False,
-                     help="""Using this enables the "No Sandbox" feature.""")
+                     help="""Using this enables the "No Sandbox" feature.
+                          (This setting is now always enabled by default.)""")
     parser.addoption('--disable_gpu', '--disable-gpu',
                      action="store_true",
                      dest='disable_gpu',
                      default=False,
-                     help="""Using this enables the "Disable GPU" feature.""")
+                     help="""Using this enables the "Disable GPU" feature.
+                          (This setting is now always enabled by default.)""")
     parser.addoption('--incognito', '--incognito_mode', '--incognito-mode',
                      action="store_true",
                      dest='incognito',
@@ -390,6 +391,13 @@ def pytest_addoption(parser):
                      default=False,
                      help="""The option to reuse the selenium browser window
                           session between tests.""")
+    parser.addoption('--crumbs',
+                     action="store_true",
+                     dest='crumbs',
+                     default=False,
+                     help="""The option to delete all cookies between tests
+                          that reuse the same browser session. This option
+                          is only needed when using "--reuse-session".""")
     parser.addoption('--maximize_window', '--maximize-window', '--maximize',
                      '--fullscreen',
                      action="store_true",
@@ -478,6 +486,7 @@ def pytest_configure(config):
     sb_config.guest_mode = config.getoption('guest_mode')
     sb_config.devtools = config.getoption('devtools')
     sb_config.reuse_session = config.getoption('reuse_session')
+    sb_config.crumbs = config.getoption('crumbs')
     sb_config.shared_driver = None  # The default driver for session reuse
     sb_config.maximize_option = config.getoption('maximize_option')
     sb_config.save_screenshot = config.getoption('save_screenshot')
@@ -488,8 +497,8 @@ def pytest_configure(config):
     if sb_config.reuse_session:
         arg_join = " ".join(sys.argv)
         if ("-n" in sys.argv) or ("-n=" in arg_join) or (arg_join == "-c"):
-            # Can't "reuse_session" if multithreaded
-            sb_config.reuse_session = False
+            # sb_config.reuse_session = False
+            pass  # Allow multithreaded browser sessions to be reused now
 
     if "linux" in sys.platform and (
             not sb_config.headed and not sb_config.headless):
