@@ -25,7 +25,7 @@ class SeleniumBrowser(Plugin):
     --headless  (The option to run tests headlessly. The default on Linux OS.)
     --headed  (The option to run tests with a GUI on Linux OS.)
     --start-page=URL  (The starting URL for the web browser when tests begin.)
-    --time-limit  (The option to set a time limit per test before failing it.)
+    --time-limit=SECONDS  (Safely fail any test that exceeds the limit limit.)
     --slow  (The option to slow down the automation.)
     --demo  (The option to visually see test actions as they occur.)
     --demo-sleep=SECONDS  (The option to wait longer after Demo Mode actions.)
@@ -37,8 +37,6 @@ class SeleniumBrowser(Plugin):
     --disable-csp  (This disables the Content Security Policy of websites.)
     --enable-sync  (The option to enable "Chrome Sync".)
     --use-auto-ext  (The option to use Chrome's automation extension.)
-    --no-sandbox  (The option to enable Chrome's "No-Sandbox" feature.)
-    --disable-gpu  (The option to enable Chrome's "Disable GPU" feature.)
     --incognito  (The option to enable Chrome's Incognito mode.)
     --guest  (The option to enable Chrome's Guest mode.)
     --devtools  (The option to open Chrome's DevTools when the browser opens.)
@@ -236,7 +234,7 @@ class SeleniumBrowser(Plugin):
             help="""The option to check for JavaScript errors after
                     every page load.""")
         parser.add_option(
-            '--ad_block', '--ad-block',
+            '--ad_block', '--ad-block', '--block_ads', '--block-ads',
             action="store_true",
             dest='ad_block_on',
             default=False,
@@ -279,13 +277,15 @@ class SeleniumBrowser(Plugin):
             action="store_true",
             dest='no_sandbox',
             default=False,
-            help="""Using this enables the "No Sandbox" feature.""")
+            help="""Using this enables the "No Sandbox" feature.
+                    (This setting is now always enabled by default.)""")
         parser.add_option(
             '--disable_gpu', '--disable-gpu',
             action="store_true",
             dest='disable_gpu',
             default=False,
-            help="""Using this enables the "Disable GPU" feature.""")
+            help="""Using this enables the "Disable GPU" feature.
+                    (This setting is now always enabled by default.)""")
         parser.add_option(
             '--incognito', '--incognito_mode', '--incognito-mode',
             action="store_true",
